## dbt-tests-adapter 1.15.1 - May 28, 2025

### Fixes

- Modify tests to exercise case differences in snapshot target meta columns. ([#1101](https://github.com/dbt-labs/dbt-adapters/issues/1101))

### Under the Hood

- Add new tests for snapshots in new_record mode in combination with check columns. ([#1068](https://github.com/dbt-labs/dbt-adapters/issues/1068))
